====================
django-codenerix-pos
====================

Codenerix POS is a module that enables `CODENERIX.com <http://www.codenerix.com/>`_ to set Point Of Services on several platforms in a general manner

.. image:: http://www.centrologic.com/wp-content/uploads/2017/01/logo-codenerix.png
    :target: http://www.codenerix.com
    :alt: Try our demo with Centrologic Cloud

****
Demo
****

Coming soon...

**********
Quickstart
**********

1. Install this package::

    For python 2: sudo pip2 install django-codenerix-pos
    For python 3: sudo pip3 install django-codenerix-pos

2. Add "codenerix_pos" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'codenerix_pos',
    ]

3. Add in settings the params::

4. Since Codenerix Products is a library, you only need to import its parts into your project and use them.

*************
Documentation
*************

Coming soon... do you help us? `Centrologic <http://www.centrologic.com/>`_

******************
Commercial support
******************

This project is backed by `Centrologic <http://www.centrologic.com/>`_. You can discover more in `CODENERIX.com <http://www.codenerix.com/>`_.
If you need help implementing or hosting django-codenerix-pos, please contact us:
http://www.centrologic.com/contacto/

.. image:: http://www.centrologic.com/wp-content/uploads/2015/09/logo-centrologic.png
    :target: http://www.centrologic.com
    :alt: Centrologic is supported mainly by Centrologic Computational Logistic Center

*******
Credits
*******

Several technologies have been used to build `CODENERIX <http://www.codenerix.com>`_:

=================================== =================== =========================== =========================================================
Project name                        License             Owner                       Link to project
=================================== =================== =========================== =========================================================
Reconnecting Websocket              MIT                 Joe Walnes                  https://github.com/joewalnes/reconnecting-websocket
=================================== =================== =========================== =========================================================
